/*
 * $Id: Codec.java 1671 2009-06-05 17:01:24Z karianna $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-0.7.10/common/src/main/java/org/ikasan/common/util/Codec.java $
 * 
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * Copyright (c) 2003-2008 Mizuho International plc. and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the 
 * Free Software Foundation Europe e.V. Talstrasse 110, 40217 Dusseldorf, Germany 
 * or see the FSF site: http://www.fsfeurope.org/.
 * ====================================================================
 */
package org.ikasan.common.util;

// Imported apache commons classes
import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.codec.binary.Hex;

/**
 * This convenient class wraps apache's commons codec.
 * 
 * @author Ikasan Development Team
 */
public class Codec
{

    /**
     * Don't let anyone instantiate this class.
     */
    private Codec()
    {
        // Do Nothing
    }

    /**
     * Encodes the incoming data using the defined encoding, if encoding is
     * supported. Currently supported encodings are:-
     * <ul>
     *   <li>base64</li>
     *   <li>hex</li>
     *   <li>noenc</li>
     * </ul>
     * 
     * @param data is the byte array data to encode.
     * @param encoding is the encoding algorithm used to encode the data.
     * @return encoded data
     */
    public static byte[] encode(byte[] data, String encoding)
    {
        if (encoding.equalsIgnoreCase("base64"))
        {
            return Base64.encodeBase64(data);
        }
        else if (encoding.equalsIgnoreCase("hex"))
        {
            return new Hex().encode(data);
        }
        else if (encoding.equalsIgnoreCase("noenc"))
        {
            return data;
        }
        else
        {
            throw new IllegalArgumentException("Unsupported encoding algorithm '" + encoding + "'");
        }
    }

    /**
     * Decodes the incoming encoded data using the defined encoding, if
     * encoding is supported. Currently supported encodings are:-
     * <ul>
     * <li>base64</li>
     * <li>hex</li>
     * <li>noenc</li>
     * </ul>
     * 
     * @param data is the byte array data to decode.
     * @param encoding is the encoding algorithm used to decode the data.
     * @return encoded data
     * @throws DecoderException 
     */
    public static byte[] decode(byte[] data, String encoding) throws DecoderException
    {
        if (encoding.equalsIgnoreCase("base64"))
        {
            return Base64.decodeBase64(data);
        }
        else if (encoding.equalsIgnoreCase("hex"))
        {
            return new Hex().decode(data);
        }
        else if (encoding.equalsIgnoreCase("noenc"))
        {
            return data;
        }
        else
        {
            throw new IllegalArgumentException("Unsupported encoding algorithm '" + encoding + "'");
        }
    }

}
